Checks if there is an internet connection with GitHub to download data.
check_connection_anp(
url = paste0("https://raw.githubusercontent.com/", "PaulESantos/perugeopkg/master/",
"metadata_anp.csv"),
silent = FALSE
)Logical. TRUE if url is working, FALSE if not.
A string with the url address of an perugpkg dataset
Logical. Throw a message when silent is FALSE (default)