Download Spatial Data of Protected Natural Areas (ANP) in Peru
Source:R/get_anp_peru.R
get_anp_peru.RdDownloads spatial data of protected natural areas in Peru declared by SERNANP (National Service of Natural Areas Protected by the State). Data were obtained from the SERNANP Geographic Information Viewer as the official source. The data use WGS 84 (EPSG:4326).
Examples
if (interactive()) {
# Read specific ANP
manu <- get_anp_peru(anp = "Manu")
}